<?php
/******************************************************************************/
/* AEL Sarl : Web hosting, datacenter, gestion et comptabilité déportées      */
/* Copyright (C) 2008 Affaires En Ligne S.A.R.L.                              */
/* Contact : contact@affaires-en-ligne.fr                                     */
/* Web : http://www.spidboutic.fr                                             */
/*                                                                            */
/* This program is free software; you can redistribute it and/or              */
/* modify it under the terms of the GNU General Public License                */
/* as published by the Free Software Foundation; either version 2             */
/* of the License, or (at your option) any later version.                     */
/*                                                                            */
/* This program is distributed in the hope that it will be useful,            */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of             */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the               */
/* GNU General Public License for more details.                               */
/*                                                                            */
/* You should have received a copy of the GNU General Public License          */
/* along with this program; if not, write to the Free Software                */
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/******************************************************************************/

/*
 * Created on 5 mars 08 by AEL Sarl for
 * 
 * osCommerce, Open Source E-Commerce Solutions
 * http://www.oscommerce.com
 *
 * Copyright (c) 2003 osCommerce
 *
 * Released under the GNU General Public License
 * 
 */

/**
 * Singleton class for logging
 */
class Logger {
	
	private static $instance;
	
	/**
	 * Build a Logger instance
	 * 
	 * @param string $logfile	the file where the logs will be appended to
	 */
	private function __construct($logfile="webmanager.log") {
		$this->logfile = $logfile;
		try {
			$this->fp = fopen($logfile, 'a');
		} catch (Exception $e) {
			$this->fp = null;
		}
	}
	
	/**
	 * Get the single instance of Logger
	 * 
	 * @param string $logfile	the file where the logs will be appended to
	 */
	public static function getInstance($logfile) {
		if (!isset(self::$instance)) {
			$cls = __CLASS__;
			self::$instance = new $cls($logfile);
		}
		return self::$instance;
	}
	
	public function __clone() {
		trigger_error('Le clônage n\'est pas autorisé.', E_USER_ERROR);
	}
	
	/**
	 * Write a message in the log file
	 * 
	 * @param string message	message to write
	 * @param string level		severity level
	 */
	private function _log($message, $level='INFO') {
		try {
			fwrite($this->fp, "[" . date("m/d/Y h:i:s", mktime()) . "] " . $level . " : " . $message . "\n");	
		} catch (Exception $e) {}
	}
	
	/**
	 * Write an info message in the log file
	 * 
	 * @param string message	message to write
	 */
	public function info($message) {
		$this->_log($message);
	}
	
	/**
	 * Write a warning message in the log file
	 * 
	 * @param string message	message to write
	 */
	public function warning($message) {
		$this->_log($message, $level='WARNING');
	}
	
	/**
	 * Write an error message in the log file
	 * 
	 * @param string message	message to write
	 */
	public function error($message) {
		$this->_log($message, $level='ERROR');
	}
}

?>
